@@ -1,23 +1,24 @@
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 import requests
 import json
 import sseclient
 
 class StreamBot:
-    def __init__(self, api_key, bot_name, genesis_prompt, openai_url = 'https://api.openai.com/v1/chat/completions'):
+    def __init__(self, api_key, bot_name, genesis_prompt, openai_url = 'https://api.openai.com/v1/chat/completions', model="gpt-3.5-turbo-0301"):
         self.api_key = api_key
         self.bot_name = bot_name
         self.genesis_prompt = genesis_prompt
         self.messages = [{"role":"system", "content": genesis_prompt}]
         self.openai_url = openai_url
+        self.model = model
 
     def add_message(self, message, role="user"):
       self.messages.append({"role": role, "content": message})
 
-    def chat(self):
+    def chat(self, messages = []):
         reqBody = {
-          "model": "gpt-3.5-turbo-0301",
+          "model": self.model,
           "messages": self.messages,
           "stream": True
       }
